@@ -421,7 +421,7 @@ Develop your own, or make alternative versions of existing xnet tools:
 def main():
     args = sys.argv[:]
 
-    if args[1] in ('-h', '--help') or len(args) < 2:
+    if len(args) < 2 or args[1] in ('-h', '--help'):
         print __xnet_usage__
         return
 
